==> qtdeclarative-opensource-src_5.2.1.orig.tar.xz: qtdeclarative-opensource-src-5.2.1/src/plugins/qmltooling/qmldbg_tcp/qtcpserverconnection.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the QtQml module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QTCPSERVERCONNECTION_H
#define QTCPSERVERCONNECTION_H

#include <QtQml/private/qqmldebugserverconnection_p.h>

QT_BEGIN_NAMESPACE

class QQmlDebugServer;
class QTcpServerConnectionPrivate;
class QTcpServerConnection : public QObject, public QQmlDebugServerConnection
{
    Q_OBJECT
    Q_DECLARE_PRIVATE(QTcpServerConnection)
    Q_DISABLE_COPY(QTcpServerConnection)
    Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QQmlDebugServerConnection")
    Q_INTERFACES(QQmlDebugServerConnection)

public:
    QTcpServerConnection();
    ~QTcpServerConnection();

    void setServer(QQmlDebugServer *server);
    void setPortRange(int portFrom, int portTo, bool bock, const QString &hostaddress);

    bool isConnected() const;
    void send(const QList<QByteArray> &messages);
    void disconnect();
    bool waitForMessage();

    void listen();
    void waitForConnection();

private Q_SLOTS:
    void readyRead();
    void newConnection();
    void invalidPacket();

private:
    QTcpServerConnectionPrivate *d_ptr;
};

QT_END_NAMESPACE

#endif // QTCPSERVERCONNECTION_H

==> qtdeclarative-opensource-src-5.3.2.tar.xz: qtdeclarative-opensource-src-5.3.2/src/plugins/qmltooling/qmldbg_tcp/qtcpserverconnection.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the QtQml module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QTCPSERVERCONNECTION_H
#define QTCPSERVERCONNECTION_H

#include <private/qqmldebugserverconnection_p.h>

QT_BEGIN_NAMESPACE

class QQmlDebugServer;
class QTcpServerConnectionPrivate;
class QTcpServerConnection : public QObject, public QQmlDebugServerConnection
{
    Q_OBJECT
    Q_DECLARE_PRIVATE(QTcpServerConnection)
    Q_DISABLE_COPY(QTcpServerConnection)
    Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QQmlDebugServerConnection")
    Q_INTERFACES(QQmlDebugServerConnection)

public:
    QTcpServerConnection();
    ~QTcpServerConnection();

    void setServer(QQmlDebugServer *server);
    void setPortRange(int portFrom, int portTo, bool bock, const QString &hostaddress);

    bool isConnected() const;
    void send(const QList<QByteArray> &messages);
    void disconnect();
    bool waitForMessage();

    void listen();
    void waitForConnection();

private Q_SLOTS:
    void readyRead();
    void newConnection();
    void invalidPacket();

private:
    QTcpServerConnectionPrivate *d_ptr;
};

QT_END_NAMESPACE

#endif // QTCPSERVERCONNECTION_H
